@@ -1,22 +1,21 @@
 """Plot to test ticker.FixedFormatter"""
 
 import matplotlib.pyplot as plt
-import numpy as np
 import mpld3
 
 
 def create_plot():
-    positions, labels = [-1, 0, 1, 10, 11], ['OUTSIDE', 'A','B','C', 'OUTSIDE']
+    positions, labels = [-1, 0, 1, 10, 11], ['OUTSIDE', 'A', 'B', 'C', 'OUTSIDE']
     plt.yticks(positions)
     plt.xticks(positions, labels)
-    plt.xlim([0,10])
-    plt.ylim([0,10])
+    plt.xlim([0, 10])
+    plt.ylim([0, 10])
     return plt.gcf()
 
 
 def test_axis():
     fig = create_plot()
-    html = mpld3.fig_to_html(fig)
+    _ = mpld3.fig_to_html(fig)
     plt.close(fig)
 
 
